@@ -1,5 +1,3 @@
-/* global axe */
-
 const possibleShadowRoots = [
 	'article',
 	'aside',
@@ -26,7 +24,7 @@ const possibleShadowRoots = [
  * @param {Node}   node  The HTML DOM node
  * @return {Boolean}
  */
-axe.utils.isShadowRoot = function isShadowRoot(node) {
+function isShadowRoot(node) {
 	if (node.shadowRoot) {
 		const nodeName = node.nodeName.toLowerCase();
 		if (
@@ -37,4 +35,6 @@ axe.utils.isShadowRoot = function isShadowRoot(node) {
 		}
 	}
 	return false;
-};
+}
+
+export default isShadowRoot;
