@@ -174,9 +174,15 @@ module.exports = {
   // Set this to true if you'd like to see timestamps next to the logging output
   output_timestamp: false,
 
+  // Set this to iso if you'd like to see timestamps as ISO strings
+  timestamp_format: '',
+
   // Set this to true if you'd like to not display errors during the execution of the test (they are shown at the end always).
   disable_error_log: false,
 
+  // By default, API command errors that don't deal with DOM elements (e.g. cookie) are ignored, unless they are thrown by Node.js (e.g. ECONNRESET errors)
+  report_command_errors: false,
+
   // Take error and failure screenshots during test execution
   screenshots: false,
 
